pub(crate) struct ExtractedBody {
pub(crate) stream: DomRoot<ReadableStream>,
pub(crate) source: BodySource,
pub(crate) total_bytes: Option<usize>,
pub(crate) content_type: Option<DOMString>,
}Expand description
Fields
stream: DomRoot<ReadableStream>source: BodySourcetotal_bytes: Option<usize>content_type: Option<DOMString>Implementations
Sourceimpl ExtractedBody
impl ExtractedBody
Sourcepub(crate) fn into_net_request_body(
self,
) -> (RequestBody, DomRoot<ReadableStream>)
pub(crate) fn into_net_request_body( self, ) -> (RequestBody, DomRoot<ReadableStream>)
Build a request body from the extracted body,
to be sent over IPC to net to use with concept-request-transmit-body,
see https://fetch.spec.whatwg.org/#concept-request-transmit-body.
Also returning the corresponding readable stream,
to be stored on the request in script,
and potentially used as part of consume_body,
see https://fetch.spec.whatwg.org/#concept-body-consume-body
Transmitting a body over fetch, and consuming it in script, are mutually exclusive operations, since each will lock the stream to a reader.